SlowDataBlockKind

Enum SlowDataBlockKind 

#[non_exhaustive]
pub enum SlowDataBlockKind { Gps, Text, HeaderRetx, FastData1, FastData2, Squelch, Unknown { high_nibble: u8, }, }
Slow data block type, recovered from the high nibble of byte 0 after descrambling.

Reference: ircDDBGateway/Common/DStarDefines.h:85-92 (SLOW_DATA_TYPE_GPS = 0x30, SLOW_DATA_TYPE_TEXT = 0x40, etc.).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Gps

0x3X — GPS NMEA passthrough.



Text

0x4X — 20-character status text.



HeaderRetx

0x5X — header retransmission.



FastData1

0x8X — fast data variant 1.



FastData2

0x9X — fast data variant 2.



Squelch

0xCX — squelch / control.



Unknown

Any other high nibble.

Fields

high_nibble: u8

The high nibble that didn’t match.

Implementations

Source

impl SlowDataBlockKind

pub const fn from_type_byte(byte: u8) -> Self

Decode the high nibble of the type byte into a kind.